@@ -74,12 +74,6 @@ def app(base_app):
     return base_app
 
 
-@pytest.fixture()
-def script_info(app):
-    """Get ScriptInfo object for testing CLI."""
-    return ScriptInfo(create_app=lambda info: app)
-
-
 @pytest.fixture()
 def queue(app):
     """Get queue object for testing bulk operations."""
